# RStudio ver 1.1.383
# Figure and table #'s refer to figures and tables  in:
# 'Planting Date Effects on Cotton Lint Yield and Fiber Quality  in the U.S. Southern High Plains'
#
library(dplyr)
library(stats)
library(base)
library(readxl)
#
options(digits = 5)
# 
setwd('/Your_Current_Directory')
# 
# May Planted Fiber Quality Data
fqual <- read_excel("LBKFiberQual2007-2017.xlsx", col_names=TRUE, sheet=1)  
# June Planted Fiber Quality Data
fqual_lp <- read_excel("LBKFiberQual2007-2017.xlsx", col_names=TRUE, sheet=2) 
#
# Inner join identifys fiber quality for cultivars planted each year in May and June
# See common fiber quality row of Table 2, Common Fiber Quality Tab of LBKFiberQual2007-2017.xlsx
fqual_fx <- inner_join(fqual,fqual_lp, by = c("year","cult") ) 
#
# Calculate May-June effects and add columns to fqual_fx data frame
fqual_fx <- fqual_fx %>% mutate(delmic  = mic-mic_lp)
fqual_fx <- fqual_fx %>% mutate(dellen  = len-len_lp)
fqual_fx <- fqual_fx %>% mutate(deluni  = uni-uni_lp)
fqual_fx <- fqual_fx %>% mutate(delstr  = str-str_lp)
fqual_fx <- fqual_fx %>% mutate(delelon = elon-elon_lp)
fqual_fx <- fqual_fx %>% mutate(delgdd  = gdd-gdd_lp)
fqual_fx <- fqual_fx %>% mutate(delchrs = chrs-chrs_lp)
fqual_fx <- fqual_fx %>% mutate(plant_delay = pldoy_lp-pldoy)
fqual_fx <- fqual_fx %>% mutate(mprime = 100.0*delmic/delchrs)
# 
# Calculate percentages in Fig. 5a & c via entering following on console
# fqual_fx %>% filter(mic >= 3.7 & mic  <= 4.2) %>% summarize(pct=n()/162)
# fqual_fx %>% filter(mic_lp >= 3.7 & mic_lp  <= 4.2) %>% summarize(pct=n()/162)
# fqual_fx %>% filter(mic <= 3.4) %>% summarize(pct=n()/162)
# fqual_fx %>% filter(mic_lp <= 3.4) %>% summarize(pct=n()/162)
# fqual_fx %>% filter(mic >= 5.0) %>% summarize(pct=n()/162)
# fqual_fx %>% filter(mic_lp >= 5.0) %>% summarize(pct=n()/162)
# ... etc.
#
# Selecting data frame columns to write to fqualefx.log
# Figs. 5,6,7  plotted from fqualefx.log via Generic Mapping Tools
columns <- c('year','mic','mic_lp','delmic','gdd','gdd_lp','delgdd','chrs','chrs_lp','delchrs','dellen','deluni','delstr','delelon','mprime','cult')
write.table(sub_fqual_fx,file="fqualefx.log",quote=FALSE)
#
# In Fig 5f calulate mean del-Micronaire effects via
Fig5f <- fqual_fx %>% group_by(year) %>% summarize(avg = mean(delmic))
write.table(Fig5f,file="Fig5f.log",quote=FALSE)
# T tests for each year in Fig. 5f
temp <- fqual_fx %>% filter(year == 2007,2008,...2017)
t.test(temp$delmic,mu=0.0,alternative="two.sided",conf.level=0.95)
# year delmic avg    p-value 
# 2007   0.040         0.60
# 2008   1.007         4.8e-09
# 2009   0.743         1.3e-07
# 2010  -0.247         9.3e-05
# 2011   0.367         1.3e-05
# 2012   0.777         0.00018
# 2013   1.185         2.8e-08
# 2014  -0.46          0.038
# 2015  -0.125         0.081
# 2016   1.036         1.3e-08
# 2017   0.796         2.1e-10
#
# Similar for Fig. 6a,b,c,d
# Length
Fig6a <- fqual_fx %>% group_by(year) %>% summarize(avg = mean(dellen))
write.table(Fig6a,file="Fig6a.log",quote=FALSE)
# Following t-tests conducted on console for each year
# temp <- fqual_fx %>% filter(year == 2007,2008,...2017)
# t.test(temp$dellen,mu=0.0,alternative="two.sided",conf.level=0.95)
## Uniformity
Fig6b <- fqual_fx %>% group_by(year) %>% summarize(avg = mean(deluni))
write.table(Fig6b,file="Fig6b.log",quote=FALSE)
# temp <- fqual_fx %>% filter(year == 2007,2008,...2017)
# t.test(temp$deluni,mu=0.0,alternative="two.sided",conf.level=0.95)
## Strength
Fig6c <- fqual_fx %>% group_by(year) %>% summarize(avg = mean(delstr))
write.table(Fig6c,file="Fig6c.log",quote=FALSE)
# temp <- fqual_fx %>% filter(year == 2007,2008,...2017)
# t.test(temp$delstr,mu=0.0,alternative="two.sided",conf.level=0.95)
## Elongation
Fig6d <- fqual_fx %>% group_by(year) %>% summarize(avg = mean(delelon))
write.table(Fig6d,file="Fig6d.log",quote=FALSE)
# temp <- fqual_fx %>% filter(year == 2007,2008,...2017)
# t.test(temp$delelon,mu=0.0,alternative="two.sided",conf.level=0.95)
#



